=======
Credits
=======

Development Lead
----------------

* Jan Herout <jan.herout@gmail.com> - author of this Merry extension
* Miguel Grinberg - author of Merry

Contributors
------------

None yet. Why not be the first?
